@@ -272,7 +272,6 @@ OC.L10N.register(
     "Select conversation" : "اختر محادثة",
     "on" : "في",
     "at" : "عند",
-    "Reminder" : "تذكير",
     "before at" : "قبل",
     "Notification" : "تنبيه",
     "Email" : "البريد الإلكتروني",
@@ -283,7 +282,6 @@ OC.L10N.register(
     "Edit time" : "تعديل الوقت",
     "Save time" : "حفظ الوقت",
     "Remove reminder" : "حذف التذكير",
-    "+ Add reminder" : "+ اضافة تذكير",
     "Add reminder" : "أضف تذكيراً",
     "seconds" : "ثوانٍ",
     "minutes" : "دقائق",
@@ -318,26 +316,25 @@ OC.L10N.register(
     "Awaiting response" : "في انتظار الرّد",
     "Checking availability" : "تحقّق من التواجد",
     "Has not responded to {organizerName}'s invitation yet" : "لم يَرُدَّ على دعوة {organizerName} بعدُ",
-    "Select automatic slot" : "إختيار الخانة الزمنية التلقائية",
     "chairperson" : "الرئيس",
     "required participant" : "المُشارِك المطلوب",
     "non-participant" : "غير مُشارِك",
     "optional participant" : "مُشارِك اختياري",
     "{organizer} (organizer)" : "{organizer} (مُنظِّم)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "مُتاحٌ",
-    "Busy (tentative)" : "مشغولٌ (حاليّاً)",
-    "Busy" : "مشغول",
-    "Out of office" : "خارج المكتب",
-    "Unknown" : "غير معروف",
     "Availability of attendees, resources and rooms" : "توافر الحضور والموارد والغرف",
-    "with" : "مع",
-    "Available times:" : "الأوقات المتاحة:",
     "Suggestion accepted" : "تمّ قبول الاقتراح",
+    "Legend" : "مفتاح تفسيري",
+    "Out of office" : "خارج المكتب",
+    "Attendees:" : "الحُضُور:",
     "Done" : "تمّ",
     "Search room" : "البحث في الغرفة",
     "Room name" : "اسم الغرفة",
     "Check room availability" : "تحقَّق من توافر الغرفة",
+    "Free" : "مُتاحٌ",
+    "Busy (tentative)" : "مشغولٌ (حاليّاً)",
+    "Busy" : "مشغول",
+    "Unknown" : "غير معروف",
     "Find a time" : "إيجاد وقت",
     "The invitation has been accepted successfully." : "تمّ قبول الدعوة بنجاح.",
     "Failed to accept the invitation." : "فشل في قبول الدعوة.",
@@ -376,7 +373,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "لم يُمكن تغيير إعداد \"كامل اليوم\" بالنسبة للأحداث التي هي جزء من مجموعة تكرارية. ",
     "From" : "مِن :",
     "To" : "إلى :",
-    "All day" : "كامل اليوم",
     "Repeat" : "كرّر",
     "_time_::_times_" : ["مرات","مرة","مرات","مرات","مرات","مرات"],
     "never" : "أبداً",
@@ -400,7 +396,7 @@ OC.L10N.register(
     "Does not repeat" : "لا يتكرر",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "لا يدعم نكست كلاود تعريف التكرار لهذا الحدث بشكل كامل. إذا قمت بتحرير خيارات التكرار، فقد تفقد بعض التكرارات.",
     "No rooms or resources yet" : "لا توجد غرف يمكن حجزها حتى الآن",
-    "Suggestions" : "مقترحات",
+    "Resources" : "الموارد",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatCapacity} مقاعد","{seatCapacity} مقعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد"],
     "Add resource" : "إضافة مورِد",
     "Has a projector" : "لديه جهاز عرض",
@@ -467,16 +463,16 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "الاكتشاف التلقائي للمنطقة الزمنية يُحدّد منطقتك الزمنية بالنسبة للتوقيت العالمي المُوحّد UTC. هذا على الأرجح نتيجة للتدابير الأمنية لمتصفح الويب الخاص بك. يُرجى ضبط المنطقة الزمنية يدويًا في إعدادات التقويم.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "لم يتم العثور على منطقتك الزمنية التي تمّت تهيئتها ({timezoneId}). تمّ الرجوع إلى التوقيت العالمي المُوحّد UTC. يرجى تغيير منطقتك الزمنية في الإعدادات، والإبلاغ عن هذه المشكلة.",
     "Availability of {displayName}" : "توافُر {displayName}",
+    "Edit event" : "تعديل الحدث",
     "Event does not exist" : "الفعالية غير موجودة",
     "Duplicate" : "تكرار",
     "Delete this occurrence" : "حذف هذا الظهور",
     "Delete this and all future" : "حذف هذا الظهور والجميع في الستقبل",
+    "All day" : "كامل اليوم",
     "Modifications wont get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
-    "Details" : "التفاصيل",
     "Managing shared access" : "إدارة الوصول المشترك",
     "Deny access" : "منع الوصول",
     "Invite" : "دعوة",
-    "Resources" : "الموارد",
     "_User requires access to your file_::_Users require access to your file_" : ["يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدم إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["تتطلب المرفقات وصولاً مشتركًا","يتطلب المرفق وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا"],
     "Untitled event" : "حدث بدون اسم",
@@ -582,6 +578,13 @@ OC.L10N.register(
     "This is an event reminder." : "هذا تذكير بحدث",
     "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
     "Appointment not found" : "الموعد غير موجود",
-    "User not found" : "المستخدم غير موجود"
+    "User not found" : "المستخدم غير موجود",
+    "Reminder" : "تذكير",
+    "+ Add reminder" : "+ اضافة تذكير",
+    "Select automatic slot" : "إختيار الخانة الزمنية التلقائية",
+    "with" : "مع",
+    "Available times:" : "الأوقات المتاحة:",
+    "Suggestions" : "مقترحات",
+    "Details" : "التفاصيل"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
