@@ -165,6 +165,8 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
+    "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat surel Anda di pengaturan pribadi.",
     "Update" : "Perbarui",
     "Location" : "Lokasi",
@@ -192,7 +194,6 @@ OC.L10N.register(
     "Edit time" : "Edit waktu",
     "Save time" : "Simpan waktu",
     "Remove reminder" : "Buang pengingat",
-    "+ Add reminder" : "+ Tambah pengingat",
     "seconds" : "detik",
     "minutes" : "menit",
     "hours" : "jam",
@@ -201,14 +202,14 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Delete file" : "Hapus berkas",
     "Not available" : "Tidak tersedia",
+    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
+    "Out of office" : "Keluar kantor",
+    "Done" : "Selesai",
+    "Room name" : "Nama ruang",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
     "Busy" : "Sibuk",
-    "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
-    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
-    "Done" : "Selesai",
-    "Room name" : "Nama ruang",
     "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
     "Failed to accept the invitation." : "Gagal menerima undangan.",
     "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
@@ -234,7 +235,6 @@ OC.L10N.register(
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
-    "All day" : "Sepanjang hari",
     "Repeat" : "Ulang",
     "never" : "tidak pernah",
     "on date" : "pada tanggal",
@@ -254,8 +254,10 @@ OC.L10N.register(
     "weekday" : "akhir pekan",
     "weekend day" : "akhir pekan",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
+    "Resources" : "Sumber daya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
+    "on {formattedDate}" : "dalam {formattedDate}",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
     "Pick a time" : "Pilih waktu",
@@ -271,8 +273,8 @@ OC.L10N.register(
     "Personal" : "Pribadi",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
-    "Details" : "Detail",
-    "Resources" : "Sumber daya",
+    "Edit event" : "Sunting agenda",
+    "All day" : "Sepanjang hari",
     "Untitled event" : "Acara tanpa judul",
     "Close" : "Tutup",
     "Subscribe to {name}" : "Berlangganan ke {name}",
@@ -340,9 +342,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "This is an event reminder." : "Ini adalah pengingat acara.",
-    "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
-    "[Today]" : "[Hari ini]",
-    "Add a description" : "Tambah deskripsi",
-    "Chat room for event" : "Ruang obrolan untuk acara"
+    "+ Add reminder" : "+ Tambah pengingat",
+    "Details" : "Detail"
 },
 "nplurals=1; plural=0;");
